==> colobot_0.1.5.orig.tar.xz: colobot-0.1.5/CONTRIBUTING.md <==
# How to contribute
**NOTE: This document is still not finished. Please feel free to suggest any changes.**

So you want to contribute to Colobot: Gold Edition? That's awesome! Before you start, read this page, it contains a lot of useful information on how to do so.

## General information
Before you start, read more about technical details of the project. They can be found on the [dev wiki](http://colobot.info/wiki/dev) and in our [Game Design Document](http://krzysh.pl:3000/project/545e90d99e8bceed2284797e)

## Before you start coding
* If you want to fix a bug, please first check the related [issue on GitHub's bug tracker](https://github.com/colobot/colobot/issues). If there isn't one, make it.
* If you want to add a new feature or make any change to gameplay, please first discuss it either [on the forums](http://colobot.info/forum) or in the related issue on GitHub. When your issue gets *enhancement* label (without the *(proposed)* part), that means that your suggestion got accepted and is waiting for somebody to work on it. Always wait for your suggestion to be accepted before you start writing any code.
* Before you start, check *"Assignee"* field in the issue and read the comments to see if nobody else is working on the same issue. If somebody is assigned to it, but there was no activity for a long time, you can take it over. Also, please post a comment on the issue that you want to help us, so other people don't waste time working at that issue in the same time.

## Coding guidelines
See the [related page on dev wiki](http://colobot.info/wiki/dev/Coding_rules).

## Submitting Pull Requests
After you finish working on your issue and want your code to be merged into the main repository, you should submit a Pull Request. Go to [this page](https://github.com/colobot/colobot/pulls) and select "New pull request". All pull request should ALWAYS be submitted to the *dev* branch. After your PR gets reviewed by our development team, it'll be merged to *dev* branch, and later to the *master* branch (on the next release).

If you need more help, see [GitHub's help page on Pull Requests](https://help.github.com/articles/using-pull-requests/).

## Need help?
Ask on our official Freenode channel (#colobot @ irc.freenode.net) or on our [forums](http://colobot.info/forum/). We're here to help :)

==> colobot_0.1.6.orig.tar.xz: colobot-0.1.6/CONTRIBUTING.md <==
# How to contribute
**NOTE: This document is still not finished. Please feel free to suggest any changes.**

So you want to contribute to Colobot: Gold Edition? That's awesome! Before you start, read this page, it contains a lot of useful information on how to do so.

## General information
Before you start, read more about technical details of the project. They can be found on the [dev wiki](http://colobot.info/wiki/dev) and in our [Game Design Document](http://compiled.colobot.info/jenkins/job/colobot-gold-gdd/lastSuccessfulBuild/artifact/Colobot_Gold_Edition-Game_Design_Document.pdf) ([live editor](http://krzysh.pl:3000/project/545e90d99e8bceed2284797e))

## Before you start coding
* If you want to fix a bug, please first check the related [issue on GitHub's bug tracker](https://github.com/colobot/colobot/issues). If there isn't one, make it.
* If you want to add a new feature or make any change to gameplay, please first discuss it either [on the forums](http://colobot.info/forum) or in the related issue on GitHub. When your issue gets *enhancement* label (without the *(proposed)* part), that means that your suggestion got accepted and is waiting for somebody to work on it. Always wait for your suggestion to be accepted before you start writing any code.
* Before you start, check *"Assignee"* field in the issue and read the comments to see if nobody else is working on the same issue. If somebody is assigned to it, but there was no activity for a long time, you can take it over. Also, please post a comment on the issue that you want to help us, so other people don't waste time working at that issue in the same time.

## Coding guidelines
See the [related page on dev wiki](http://colobot.info/wiki/dev/Coding_rules).

## Submitting Pull Requests
After you finish working on your issue and want your code to be merged into the main repository, you should submit a Pull Request. Go to [this page](https://github.com/colobot/colobot/pulls) and select "New pull request". All pull request should ALWAYS be submitted to the *dev* branch. After your PR gets reviewed by our development team, it'll be merged to *dev* branch, and later to the *master* branch (on the next release).

If you need more help, see [GitHub's help page on Pull Requests](https://help.github.com/articles/using-pull-requests/).

## Need help?
Ask on our official Freenode channel (#colobot @ irc.freenode.net) or on our [forums](http://colobot.info/forum/). We're here to help :)
